DelegatedDatabase class

A database engine (implements QueryExecutor) that delegates the relevant work to a DatabaseDelegate.

Inheritance

Constructors

DelegatedDatabase(DatabaseDelegate delegate, {bool? logStatements, bool isSequential = false})
Constructs a delegated database by providing the delegate.

Properties

delegate → DatabaseDelegate
The DatabaseDelegate to send queries to.
final
dialect → SqlDialect
The SqlDialect to use for this database engine.
no setteroverride
hashCode → int
The hash code for this object.
no setterinherited
impl → QueryDelegate
no setter
isSequential → bool
final
logStatements ↔ bool
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

beginTransaction() → TransactionExecutor
Starts a TransactionExecutor.
override
close() → Future<void>
Closes this database connection and releases all resources associated with it. Implementations should also handle close calls in a state where the database isn't open.
override
ensureOpen(QueryExecutorUser user) → Future<bool>
Opens the executor, if it has not yet been opened.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
runBatched(BatchedStatements statements) → Future<void>
Prepares and runs statements.
inherited
runCustom(String statement, [List<Object?>? args]) → Future<void>
Runs a custom SQL statement without any variables. The result of that statement will be ignored.
inherited
runDelete(String statement, List<Object?> args) → Future<int>
Runs an delete statement and returns how many rows where affected.
inherited
runInsert(String statement, List<Object?> args) → Future<int>
Runs an insert statement with the given variables. Returns the row id or the auto_increment id of the inserted row.
inherited
runSelect(String statement, List<Object?> args) → Future<List<Map<String, Object?>>>
Runs a select statement with the given variables and returns the raw results.
inherited
runUpdate(String statement, List<Object?> args) → Future<int>
Runs an update statement with the given variables and returns how many rows where affected.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited