SqlJsDatabase class

Dart wrapper around a sql database provided by the sql.js library.

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
userVersion ↔ int
Returns the user_version pragma from sqlite.
getter/setter pair

Methods

close() → void
Runs close on the underlying js api
export() → Uint8List
Runs export on the underlying js api
lastInsertId() → int
The row id of the last inserted row. This counter is reset when calling export.
lastModifiedRows() → int
Returns the amount of rows affected by the most recent INSERT, UPDATE or DELETE statement.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
prepare(String sql) → PreparedStatement
Calls prepare on the underlying js api
run(String sql) → void
Calls run(sql) on the underlying js api
runWithArgs(String sql, List args) → void
Calls run(sql, args) on the underlying js api
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited